@@ -1,10 +1,11 @@
-`.First.lib` <-
+.First.lib <-
 function (lib, pkg) 
 {
-    if (TestRWMSetup()) {
+    if (testrwm()) {
         setwd(.UserDirectory)
         cat(paste("Current directory:", .UserDirectory), fill = TRUE)
     }
-    else cat("Please run `InitializeRWM()`. Then quit R and reload it", 
+    else cat("Please run `initrwm()`. Then quit R and reload it", 
         fill = TRUE)
 }
+
